<?php

/* 
 * Widget for family friendly plugin
 * Distributed under GNU GENERAL PUBLIC LICENSE - please see license.txt for more details
    Copyright (C) 2018  James Konik
 */

class Family_Friendly_Widget extends WP_Widget {
    
    /**
    * Family Friendly Widget
    * @since    1.0.0
    *
    * @var      string
    */
    protected $widget_slug = 'family-friendly-widget';

    // constructor
    public function __construct() {
        // Hooks fired when the Widget is activated and deactivated
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        parent::__construct(
                $this->get_widget_slug(),
                __( 'Family Friendly', $this->get_widget_slug() ),
                array(
                        'classname'  => $this->get_widget_slug().'-class',
                        'description' => __( 'Family friendly user options.', $this->get_widget_slug() )
                )
        );
    }

    /**
     * Return the widget slug.
     * @since    1.0.0
     * @return    Plugin slug variable.
     */
    public function get_widget_slug() {
        return $this->widget_slug;
    }

    /**
     * Fired when the plugin is activated.
     * @param  boolean $network_wide True if WPMU superadmin uses "Network Activate" action, false if WPMU is disabled or plugin is activated on an individual blog.
     */
    public function activate( $network_wide ) {
    }

    /**
     * Fired when the plugin is deactivated.
     * @param boolean $network_wide True if WPMU superadmin uses "Network Activate" action, false if WPMU is disabled or plugin is activated on an individual blog
     */
    public function deactivate( $network_wide ) {
    }

    /**
     * Outputs the content of the widget.
     * @param array args  The array of form elements
     * @param array instance The current instance of the widget
     */
    public function widget( $args, $instance ) {
        //get the options
        $O = get_option( 'family-friendly-options' );

        //don't show the widget if the option to show it is not checked
        if( ! $O['family_friendly_show_widget'] ) {
            return;
        }

        // Check if there is a cached output
        $cache = wp_cache_get( $this->get_widget_slug(), 'widget' );
        if ( ! is_array( $cache ) ) {
            $cache = array();
        }

        if ( ! isset ( $args['widget_id'] ) ) {
            $args['widget_id'] = $this->id;
        }

        if ( isset ( $cache[ $args['widget_id'] ] ) ) {
            return print $cache[ $args['widget_id'] ];
        }

        /*
         * Doing this instead of extract, which breaches style guidelines
         */
        if( ! isset ( $name ) ) {
            $name = $args['name'];
        }
        if( ! isset ( $id ) ) {
            $id = $args['id'];
        }
        if( ! isset ( $description ) ) {
            $description = $args['description'];
        }
        if( ! isset ( $class ) ) {
            $class = $args['class'];
        }
        if( ! isset ( $before_widget ) ) {
            $before_widget = $args['before_widget'];
        }
        if( ! isset ( $after_widget ) ) {
            $after_widget = $args['after_widget'];
        }
        if( ! isset ( $before_title ) ) {
            $before_title = $args['before_title'];
        }
        if( ! isset ( $after_title ) ) {
            $after_title = $args['after_title'];
        }
        if( ! isset ( $widget_id ) ) {
            $widget_id = $args['widget_id'];
        }
        if( ! isset ( $widget_name ) ) {
            $widget_name = $args['widget_name'];
        }

        $widget_string = $before_widget;

        ob_start();

        //widget title/heading
        print'<h2 class="widget-title">'.$O['family_friendly_widget_title'].'</h2>';
        print( $O['family_friendly_main_widget_text'] );

        $widget_string .= ob_get_clean();

        $cache[ $args['widget_id'] ] = $widget_string;
        wp_cache_set( $this->get_widget_slug(), $cache, 'widget' );
        print $widget_string;

        $ulevel =family_friendly_get_user_level();
        //add this style to mark selected image
        $insert_selected_style='style="border:3px solid orange; box-shadow: 0px 2px 4px 1px #333; -webkit-box-shadow: 0px 2px 4px 1px #333;"';
        $unselected_style='style="-webkit-box-shadow: none;  -moz-box-shadow: none;  box-shadow: none;"';
        $extra = "";
        print('<p /><span style="-webkit-box-shadow: none ;  -moz-box-shadow: none ;  box-shadow: none ;">');
        if( $O[ 'family_friendly_use_green' ] ) {
            if( $ulevel == FAMILY_FRIENDLY_USER_LEVEL_GREEN ){
                $extra = $insert_selected_style;
            } else {
                $extra = $unselected_style;
            }
            print'<a style="-webkit-box-shadow: none;  -moz-box-shadow: none ;  box-shadow: none;" href="'.site_url().'?family_friendly_setting=green"><img '.$extra.' src="'.plugins_url( 'img/U.png', __FILE__ ).'" alt="rating-U" /></a>';
            $extra = "";
        }

        if( $O[ 'family_friendly_use_yellow' ] ) {
            if( $ulevel == FAMILY_FRIENDLY_USER_LEVEL_YELLOW ){
                $extra = $insert_selected_style;
            } else {
                $extra = $unselected_style;
            }
            print'<a style="-webkit-box-shadow: none;  -moz-box-shadow: none;  box-shadow: none;" href="'.site_url().'?family_friendly_setting=yellow"><img '.$extra.' src="'.plugins_url( 'img/PG.png', __FILE__ ).'" alt="rating-PG" /></a>';
            $extra = "";
        }

        if( $O[ 'family_friendly_use_red' ] ) {
            if( $ulevel == FAMILY_FRIENDLY_USER_LEVEL_RED ){
                $extra = $insert_selected_style;
            } else {
                $extra = $unselected_style;
            }
            print'<a style="-webkit-box-shadow: none;  -moz-box-shadow: none;  box-shadow: none;" href="'.site_url().'?family_friendly_setting=red"><img '.$extra.' src="'.plugins_url( 'img/18.png', __FILE__ ).'" alt="rating-18" /></a>';
            $extra="";
        }
        print('</span><p />');

        if( $O['family_friendly_cookie_warning'] ) {
            print( $O['family_friendly_cookie_warning_text']);
        }

        //show a warning if cookies are disabled (and the option is ticked in settings)
        if( $O['family_friendly_cookies_disabled_warning'] ) {
            print( '<script>'
                . 'if ( !navigator.cookieEnabled ){document.write("<br>Cookies are currently disabled.")};</script> ' );
        }

        print( $after_widget);

    } // end widget

}

?>